#!/usr/bin/env python
# -*- coding: utf8 -*-

# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

try:
    # Try to load SOS 3 API
    from sos.plugins import Plugin, RedHatPlugin
except ImportError:
    # Failed import, revert to 1.x/2.2 SOS API, and set dummy classes
    import sos.plugintools
    Plugin = RedHatPlugin = sos.plugintools.PluginBase

import os


# Derive our plugin from the Dummy one
class ocfs2(Plugin, RedHatPlugin):
    """SOS plugin for ocfs2
    """

    version = '1.1.0'

    # If we are in pre - 3.0 API, make aliases to old calls
    def addCopySpecCompat(self, copyspecs):
        if not isinstance(copyspecs, list):
            copyspecs = [copyspecs]
        for copyspec in copyspecs:
            Plugin.addCopySpec(self, copyspec)

    if not hasattr(Plugin, 'add_copy_spec'):
        add_copy_spec = addCopySpecCompat
        add_copy_spec_limit = Plugin.addCopySpecLimit
        add_cmd_output = Plugin.collectExtOutput
        if hasattr(Plugin, "getOption"):
            # SOS 2.x
            get_option = Plugin.getOption
        else:
            # SOS 1.7
            get_option = Plugin.isOptionEnabled
        # Comment out next line if you don't have any option
        # optionList = option_list

    # Comment out next method if you don't have a check_enabled() method:
    def checkenabled(self):
        return self.check_enabled()

    def check_enabled(self):
        return os.path.exists("/etc/ocfs2/cluster.conf")

    def setup(self):
        self.add_copy_spec("/etc/ocfs2/cluster.conf")
        self.add_cmd_output("/sbin/service o2cb status", suggest_filename="o2cb.status")
        self.add_cmd_output("/sbin/service ocfs2 status", suggest_filename="ocfs2.status")
        self.add_cmd_output("/sbin/mounted.ocfs2 -d", suggest_filename="mounted.ocfs2-d")
        self.add_cmd_output("/sbin/mounted.ocfs2 -f", suggest_filename="mounted.ocfs2-f")
        self.add_cmd_output("/bin/cat /etc/ocfs2/cluster.conf", suggest_filename="ocfs2.cluster.conf")
        self.add_cmd_output("/bin/sh -c '/bin/rpm -qa | /bin/egrep -e kernel.*`uname -r`'", suggest_filename="kernel.rpms.version")
        self.add_cmd_output("/bin/sh -c '/bin/rpm -qa | /bin/egrep -e ^ocfs'", suggest_filename="ocfs2.rpm.version")
        self.add_cmd_output("/sbin/fdisk -l", suggest_filename="fdisk")
        if os.path.exists("/sys/kernel/config/cluster"):
            # configfs mounted
            # List cluster node name and number
            self.add_cmd_output("/bin/sh -c 'shopt -s nullglob; for cluster in /sys/kernel/config/cluster/*/node; do cd $cluster; for node in *; do echo \"$node $(cat $node/num)\"; done; done'", suggest_filename="ocfs2_cluster_nodes_list")
            self.add_cmd_output("/bin/sh -c 'cd /sys/kernel/config/cluster && grep -r . .'", suggest_filename="ocfs2_cluster_information")
